Learn R Programming

EScvtmle (version 0.0.2)

print.EScvtmle: print.EScvtmle

Description

Prints output from object produced by ES.cvtmle function

Usage

# S3 method for EScvtmle
print(x, ...)

Value

No return value. Called to print a summary of the results for objects of class "EScvtmle".

Arguments

x

An object of class "EScvtmle"

...

Other arguments to print

Details

Prints the average treatment effect (ATE) point estimate and 95% confidence interval for the ES-CVTMLE estimator (object of class "EScvtmle") using the estimated bias squared plus variance experiment-selector. If a negative control outcome (NCO) is available, this function also prints the ATE point estimate and 95% confidence interval for the selector that includes the estimated ATE on the NCO in the bias term. See Dang et al. (2022) <arXiv:2210.05802> for more details.